@@ -40,9 +40,9 @@ from instaui.components.component import Component
 
 
 from instaui.common.var_track_mixin import mark_as_used
+from instaui.event.event_mixin import EventMixin
 
 if TYPE_CHECKING:
-    from instaui.event.event_mixin import EventMixin
     from instaui.vars.types import TMaybeRef
 
 
@@ -164,12 +164,49 @@ class Element(Component):
     def __exit__(self, *_) -> None:
         self._slot_manager.default.__exit__(*_)
 
-    def scoped_style(self, style: str, *, selector="*", with_self=False):
+    def scoped_style(
+        self,
+        style: str,
+        *,
+        selector: Union[str, Callable[[str], str]] = "*",
+        with_self=False,
+    ):
+        """
+        Applies scoped CSS styles to child elements within the component.
+
+        Args:
+            style (str): The CSS style rules to be applied within the scope.
+            selector (Union[str, Callable[[str], str]], optional): CSS selector or function
+                that generates a selector to target specific child elements. Defaults to "*".
+            with_self (bool, optional): If True, applies the styles to the component itself
+                in addition to its children. Defaults to False.
+
+        Example:
+        .. code-block:: python
+            # Apply red outline to all direct children
+            ui.column().scoped_style("outline: 1px solid red;")
+
+            # Apply styles only to elements with specific class
+            ui.box().scoped_style("color: blue;", selector=".target-class")
+
+            # Apply styles to component itself and children
+            ui.column().scoped_style("outline: 1px solid red;", with_self=True)
+
+            # Use lambda function for dynamic selector generation
+            ui.box().scoped_style(
+                "outline: 1px solid red;",
+                selector=lambda t: f"{t}:has(.hover) .target"
+            )
+        """
         app = get_app_slot()
         ssid = app.gen_scoped_style_group_id()
 
         select_box = f"*[insta-scoped-style={ssid}]"
-        real_selector = f"{select_box} {selector}"
+        real_selector = (
+            f"{select_box} {selector}"
+            if isinstance(selector, str)
+            else selector(select_box)
+        )
 
         if with_self:
             real_selector = f"{select_box},{real_selector}"
@@ -272,6 +309,25 @@ class Element(Component):
         return self
 
     def add_slot(self, name: str) -> Slot:
+        """
+        Creates and adds a new named slot to the current component, returning the slot object for further use.
+
+        Args:
+            name (str): The name of the slot to create and add. This name is used to reference the slot within the component.
+
+        Example:
+        .. code-block:: python
+            cp = some_component()
+
+            # Default slot
+            with cp as default_slot:
+                html.span(default_slot.slot_props("count"))
+
+            # Add a named footer slot
+            with cp.add_slot("footer") as footer_slot:
+                html.span(footer_slot.slot_props("count"))
+        """
+
         return self._slot_manager.get_slot(name)
 
     @overload
@@ -291,26 +347,36 @@ class Element(Component):
             VForItem,
         ],
     ) -> Self:
-        """Add classes to the component.
+        """
+        Adds one or more CSS classes to the element, supporting static strings,
+        reactive string references, or conditional class bindings.
 
         Args:
-            add (Union[ str, dict[str, TMaybeRef[bool]], TMaybeRef[str], VForItem, ]): classes to add.
+            add (str | dict[str, TMaybeRef[bool]] | TMaybeRef[str] | VForItem):
+                CSS class configuration to apply. It can be:
+                - A static class name string.
+                - A reactive reference to a dynamic class name string.
+                - A dictionary mapping class names to reactive boolean values,
+                which toggle classes on or off.
+                - A loop item reference when used inside v-for style bindings.
 
-
-        Examples:
+        Example:
         .. code-block:: python
+            from instaui import ui, html
 
-            elemelt = html.span('test')
-            elemelt.classes('class1 class2')
+            # Static class
+            html.span("target").classes("test")
 
-            # dynamically classes
-            class_name = ui.state('x')
-            elemelt.classes(class_name)
+            # Dynamic class string
+            ref = ui.state("c1")
+            html.span("target").classes(ref)
 
-            # apply name if True
-            apply = ui.state(True)
-            elemelt.classes({'x': apply})
+            # Conditional class binding
+            c1 = ui.state(True)
+            c2 = ui.state(False)
+            html.span("target").classes({"c1": c1, "c2": c2})
         """
+
         mark_as_used(add)
 
         if isinstance(add, str):
@@ -327,6 +393,32 @@ class Element(Component):
         return self
 
     def style(self, add: Union[str, dict[str, Any], TMaybeRef[str]]) -> Self:
+        """
+        Applies inline CSS styles to the element. Supports static strings, dictionaries, or reactive references
+        to dynamically update styles.
+
+        Args:
+            add (Union[str, dict[str, Any], TMaybeRef[str]]): The style(s) to apply. Can be:
+                - A CSS string (e.g., "color: red;")
+                - A dictionary mapping CSS properties to values (e.g., {"color": "red"})
+                - A reactive reference to a string or dictionary for dynamic updates.
+
+        Example:
+        .. code-block:: python
+            from instaui import ui, html
+
+            # Apply static string style
+            html.span("inline style").style("color: red;")
+
+            # Apply dictionary style
+            ref = ui.state("red")
+            html.span("target").style({"color": ref})
+
+            # Apply reactive string style
+            style = ui.state("color: red;")
+            html.span("target").style(style)
+        """
+
         mark_as_used(add)
 
         if isinstance(add, str):
@@ -355,6 +447,38 @@ class Element(Component):
         return self
 
     def props(self, add: Union[str, dict[str, Any], TMaybeRef]) -> Self:
+        """
+        Applies one or more HTML properties to the element. Supports constant values,
+        string boolean attributes, reactive bindings, and dynamic evaluated props.
+
+        Args:
+            add (Union[str, dict[str, Any], TMaybeRef]):
+                The property source to apply.
+                - If a string, the property is treated as a boolean attribute (e.g., "disabled").
+                - If a dict, key-value pairs are applied as element properties.
+                - If a reactive reference (state), the property updates automatically
+                when the referenced value changes.
+
+        Example:
+        .. code-block:: python
+            from instaui import ui, html
+
+            # Apply constant dictionary
+            html.button("Submit").props({"disabled": True})
+
+            # Apply boolean attribute using a string
+            html.button("Click").props("disabled")
+
+            # Bind reactive state to a property
+            value = ui.state(True)
+            html.checkbox(value)
+            html.button("Submit").props({"disabled": value})
+
+            # Apply dictionary state with multiple properties
+            value = ui.state({"disabled": True})
+            html.button("target").props(value)
+        """
+
         mark_as_used(add)
 
         if isinstance(add, str):
@@ -408,6 +532,10 @@ class Element(Component):
         extends: Optional[list] = None,
         modifier: Optional[list[TEventModifier]] = None,
     ):
+        assert isinstance(handler, EventMixin), (
+            "handler must be an instance of EventMixin"
+        )
+
         event_name, real_modifier = event_modifier.parse_event_modifiers(
             event_name, modifier
         )
@@ -433,6 +561,29 @@ class Element(Component):
         return self
 
     def element_ref(self, ref: ElementRef):
+        """
+        Associates an `ElementRef` with the component, allowing interaction with
+        the underlying UI element from Python or through event callbacks.
+
+        Args:
+            ref (ElementRef): A reference object used to access or manipulate
+                the rendered UI element programmatically.
+
+        Example:
+        .. code-block:: python
+            from instaui import ui, html
+            from custom import Counter
+
+            cp = ui.element_ref()
+
+            @ui.event(outputs=[cp])
+            def on_click():
+                return ui.run_element_method("reset")
+
+            Counter().element_ref(cp)
+            html.button("reset").on_click(on_click)
+        """
+
         mark_as_used(ref)
         self.__element_ref = mark_binding(ref)
         return self
