@@ -1,21 +1,18 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Optional, Union
+from typing import Any, Optional, Union
 from instaui.components.element import Element
 from instaui.components.value_element import ValueElement
 from instaui.components.mixins import CanDisabledMixin
 from ._mixins import InputEventMixin
 
-if TYPE_CHECKING:
-    from instaui.vars.types import TMaybeRef
-
 
 class Input(InputEventMixin, CanDisabledMixin, ValueElement[str]):
     def __init__(
         self,
-        value: Union[str, TMaybeRef[str], None] = None,
+        value: Union[str, Any, None] = None,
         *,
-        model_value: Union[str, TMaybeRef[str], None] = None,
-        disabled: Optional[TMaybeRef[bool]] = None,
+        model_value: Union[str, Any, None] = None,
+        disabled: Optional[bool] = None,
     ):
         super().__init__("input", value, is_html_component=True)
 
