@@ -69,6 +69,30 @@ class PathVar(PathableMixin):
     def __radd__(self, other: str):
         return other + PathTrackerBindable(self)
 
+    def __sub__(self, other: Union[int, float]):
+        return PathTrackerBindable(self) - other
+
+    def __rsub__(self, other: Union[int, float]):
+        return other - PathTrackerBindable(self)
+
+    def __mul__(self, other: Union[int, float]):
+        return PathTrackerBindable(self) * other
+
+    def __rmul__(self, other: Union[int, float]):
+        return other * PathTrackerBindable(self)
+
+    def __truediv__(self, other: Union[int, float]):
+        return PathTrackerBindable(self) / other
+
+    def __rtruediv__(self, other: Union[int, float]):
+        return other / PathTrackerBindable(self)
+
+    def __and__(self, other: Any):
+        return other & PathTrackerBindable(self)
+
+    def __or__(self, other: Any):
+        return other | PathTrackerBindable(self)
+
     def __lt__(self, other):
         return PathTrackerBindable(self) < other
 
@@ -111,6 +135,30 @@ class PathTracker(PathableMixin):
     def __radd__(self, other: str) -> Self:
         return self.__new_self__([*self.paths, PathInfo("~+", [other])])
 
+    def __sub__(self, other: Union[int, float]):
+        return self.__new_self__([*self.paths, PathInfo("-", [other])])
+
+    def __rsub__(self, other: Union[int, float]):
+        return self.__new_self__([*self.paths, PathInfo("~-", [other])])
+
+    def __mul__(self, other: Union[int, float]):
+        return self.__new_self__([*self.paths, PathInfo("*", [other])])
+
+    def __rmul__(self, other: Union[int, float]):
+        return self.__new_self__([*self.paths, PathInfo("~*", [other])])
+
+    def __truediv__(self, other: Union[int, float]):
+        return self.__new_self__([*self.paths, PathInfo("/", [other])])
+
+    def __rtruediv__(self, other: Union[int, float]):
+        return self.__new_self__([*self.paths, PathInfo("~/", [other])])
+
+    def __and__(self, other: Any):
+        return self.__new_self__([*self.paths, PathInfo("&&", [other])])
+
+    def __or__(self, other: Any):
+        return self.__new_self__([*self.paths, PathInfo("||", [other])])
+
     def __lt__(self, other):
         return self.__new_self__([*self.paths, PathInfo("<", [other])])
 
