@@ -11,6 +11,7 @@ from typing import (
     cast,
 )
 from typing_extensions import ParamSpec
+from collections.abc import Hashable
 
 from instaui.common.jsonable import Jsonable
 from instaui.runtime import get_app_slot, try_new_scope_on_ui_state
@@ -68,6 +69,7 @@ class WebComputed(
         deep_compare_on_input: bool = False,
         pre_setup: Optional[list] = None,
         debug_info: Optional[dict] = None,
+        extra_key: Optional[Sequence[Hashable]] = None,
     ) -> None:
         self._define_scope = try_new_scope_on_ui_state()
         self._org_inputs = inputs or []
@@ -107,6 +109,8 @@ class WebComputed(
             ],
         )
 
+        self._extra_key = extra_key
+
     def __call__(self, *args: P.args, **kwargs: P.kwargs) -> R:
         return self._fn(*args, **kwargs)
 
@@ -116,11 +120,14 @@ class WebComputed(
         app = get_app_slot()
 
         hkey = watch_handler.create_handler_key(
-            page_path=app.page_path,
-            handler=self._fn,
+            page_path=app.page_path, handler=self._fn, extra_key=self._extra_key
         )
 
-        watch_handler.register_handler(hkey, self._fn, len(self._outputs) + 1)
+        watch_handler.register_handler(
+            hkey,
+            self._fn,
+            len(self._outputs) + 1,
+        )
 
         data["id"] = self.__var_tracker.var_id
 
@@ -170,6 +177,7 @@ def web_computed(
     evaluating: Optional[Any] = None,
     deep_compare_on_input: bool = False,
     pre_setup: Optional[list] = None,
+    extra_key: Optional[Sequence[Hashable]] = None,
     debug_info: Optional[dict] = None,
 ):
     """
@@ -219,6 +227,7 @@ def web_computed(
                 deep_compare_on_input=deep_compare_on_input,
                 pre_setup=pre_setup,
                 debug_info=debug_info,
+                extra_key=extra_key,
             ),
         )
 
